==> ldap_auth-8.x-1.28.tar.gz: ldap_auth/src/Form/MiniorangeUserSync.php <==
<?php

/**
 * @file
 * Contains \Drupal\miniorange_ldap\Form\usersync.
 */

namespace Drupal\ldap_auth\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\ldap_auth\MiniorangeLdapSupport;
use Drupal\ldap_auth\Utilities;

class MiniorangeUserSync extends FormBase{
    public function getFormId()
    {
        return 'user_sync';
    }

    public function buildForm( array $form, FormStateInterface $form_state )
    {
        global $base_url;
        $attachments['#attached']['library'][] = 'ldap_auth/ldap_auth.admin';
        $form['markup_library'] = array(
           '#attached' => array(
               'library' => array(
              "ldap_auth/ldap_auth.admin",
          )
      ),
  );

 /*
 *  All Inclusive feature showcase
 */

        $form['markup_top'] = array(
            '#markup' => t('<div class="mo_ldap_table_layout_1"><div class="mo_ldap_table_layout container" >
                           <h3 ><span>Directory and Password Sync <i>[ <a href= "' . $base_url .'/admin/config/people/ldap_auth/Licensing"><b>All Inclusive</b></a> ]</i><a class="button button--primary" style="float:right;" href ="https://plugins.miniorange.com/guide-to-configure-ldap-ad-integration-module-for-drupal" target="_blank">Setup Guide</a></span></h3><br> <hr><br>')
        );

        $form['gatway_question']=array(
            '#markup'=> '<div class="mo_ldap_highlight_background_note_1" >
            These feature allows you to perform of directory & password synchronization for your Drupal users with any LDAP Directory and vice versa.</div><br>'
        );

         $form['ldap_register_in_AD'] =array(
             '#type'=> 'checkbox',
             '#disabled'=>TRUE,
             '#title'=> t('Create users in Active Directory/LDAP Server when a user is created in Drupal.')
         );

        $form['ldap_update_in_AD'] =array(
            '#type'=> 'checkbox',
            '#disabled'=>TRUE,
            '#title'=> t('Update user information in Active Directory/LDAP when user information is updated in Drupal.')
        );

        $form['ldap_sync_from_AD'] =array(
            '#type'=> 'checkbox',
            '#disabled'=>TRUE,
            '#title'=> t('Update user password in your LDAP/AD server when a user resets the password in Drupal .')
        );

        $form['ldap_sync_feature_AD'] =array(
          '#type'=> 'checkbox',
          '#disabled'=>TRUE,
          '#title'=> t('Import Users from your LDAP/AD server on cron')
        );

        $form['ldap_unsync_from_drupal'] =array(
            '#type'=> 'checkbox',
            '#disabled'=>TRUE,
            '#title'=> t('Disable/Block non LDAP users in Drupal upon Importing users from your LDAP/AD server.<br><br><br>')
        );

      $form['save_config_dps'] = array(
        '#type' => 'submit',
        '#value' => t('Save Changes'),
        '#disabled' => TRUE,
      );

      $form['import_user'] = array(
        '#type' => 'submit',
        '#value' => t('Import All Users From LDAP'),
        '#disabled' => TRUE,

      );

      $form['mo_markup_div_imp_2']=array('#markup'=>'</div>');
      Utilities::AddSupportButton($form, $form_state);
      return $form;
    }

    public function submitForm(array &$form, FormStateInterface $form_state){
    }

  function saved_support(array &$form, FormStateInterface $form_state) {
    Utilities::saved_support($form,$form_state);
  }

  function setup_call(array &$form, FormStateInterface $form_state){
    Utilities::setup_call($form,$form_state);
  }


}

==> ldap_auth-8.x-1.30.tar.gz: ldap_auth/src/Form/MiniorangeUserSync.php <==
<?php

/**
 * @file
 * Contains \Drupal\miniorange_ldap\Form\usersync.
 */

namespace Drupal\ldap_auth\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;
use Drupal\ldap_auth\MiniorangeLdapSupport;
use Drupal\ldap_auth\Utilities;

class MiniorangeUserSync extends FormBase{
    public function getFormId()
    {
        return 'user_sync';
    }

    public function buildForm( array $form, FormStateInterface $form_state )
    {
        global $base_url;
        $attachments['#attached']['library'][] = 'ldap_auth/ldap_auth.admin';
        $form['markup_library'] = array(
           '#attached' => array(
               'library' => array(
              "ldap_auth/ldap_auth.admin",
          )
      ),
  );

 /*
 *  All Inclusive feature showcase
 */
       $form['markup_top'] = array(
            '#markup' => t('<div class="mo_ldap_table_layout_1"><div class="mo_ldap_table_layout container" >
                           <h3 ><span>Directory and Password Sync <i>[ <a href= "' . $base_url .'/admin/config/people/ldap_auth/Licensing"><b>All Inclusive</b></a> ]</i><a class="button button--primary" style="float:right;" href ="https://plugins.miniorange.com/guide-to-configure-ldap-ad-integration-module-for-drupal" target="_blank">Setup Guide</a></span></h3><br> <hr><br>')
        );

        $form['gatway_question']=array(
            '#markup'=> '<div class="mo_ldap_highlight_background_note_1" >
            These features allows you to perform Directory & Password synchronization operations for your Drupal users with any LDAP Directory and vice versa.</div><br>'
        );

         $form['ldap_register_in_AD'] =array(
             '#type'=> 'checkbox',
             '#disabled'=>TRUE,
             '#title'=> t('Create users in Active Directory/LDAP Server when a user is created in Drupal.')
         );

        $form['ldap_update_in_AD'] =array(
            '#type'=> 'checkbox',
            '#disabled'=>TRUE,
            '#title'=> t('Update user information in Active Directory/LDAP when user information is updated in Drupal.')
        );

        $form['ldap_sync_from_AD'] =array(
            '#type'=> 'checkbox',
            '#disabled'=>TRUE,
            '#title'=> t('Update user password in your LDAP/AD server when a user resets the password in Drupal .')
        );

        $form['ldap_sync_feature_AD'] =array(
          '#type'=> 'checkbox',
          '#disabled'=>TRUE,
          '#title'=> t('Import Users from your LDAP/AD server on cron')
        );

        $form['ldap_unsync_from_drupal'] =array(
            '#type'=> 'checkbox',
            '#disabled'=>TRUE,
            '#title'=> t('Disable/Block non LDAP users in Drupal upon Importing users from your LDAP/AD server.<br><br><br>')
        );

      $form['save_config_dps'] = array(
        '#type' => 'submit',
        '#value' => t('Save Changes'),
        '#disabled' => TRUE,
      );

      $form['import_user'] = array(
        '#type' => 'submit',
        '#value' => t('Import All Users From LDAP'),
        '#disabled' => TRUE,

      );

      $form['mo_markup_div_imp_2']=array('#markup'=>'</div>');
      Utilities::AddSupportButton($form, $form_state);
      return $form;
    }

    public function submitForm(array &$form, FormStateInterface $form_state){
    }

  function saved_support(array &$form, FormStateInterface $form_state) {
    Utilities::saved_support($form,$form_state);
  }

  function setup_call(array &$form, FormStateInterface $form_state){
    Utilities::setup_call($form,$form_state);
  }


}
